@@ -206,7 +206,8 @@ class PSBaseParser(object):
         read_bytes = self.fp.read(self.BUFSIZ)
         if not isinstance(read_bytes, bytes):
             raise Exception("Files read with PSParser must be opened in binary mode")
-        self.buf = read_bytes.decode('ascii', errors='replace')
+        self.rawbuf = read_bytes
+        self.buf = read_bytes.decode('latin-1')
         if not self.buf:
             raise PSEOF('Unexpected EOF')
         self.charpos = 0
@@ -256,7 +257,7 @@ class PSBaseParser(object):
             self.fp.seek(pos)
             read_bytes = self.fp.read(prevpos-pos)
             if not read_bytes: break
-            s = read_bytes.decode('ascii', errors='replace')
+            s = read_bytes.decode('latin-1')
             while True:
                 n = max(s.rfind('\r'), s.rfind('\n'))
                 if n == -1:
@@ -424,6 +425,8 @@ class PSBaseParser(object):
             if self.paren: # WTF, they said balanced parens need no special treatment.
                 self._curtoken += c
                 return j+1
+        if any(ord(c) > 0x7f for c in self._curtoken): # need to be a bytes token!
+            self._curtoken = self._curtoken.encode('latin-1')
         self._add_token(self._curtoken)
         self._parse1 = self._parse_main
         return j+1
@@ -467,8 +470,14 @@ class PSBaseParser(object):
             return len(s)
         j = m.start(0)
         self._curtoken += s[i:j]
-        token = HEX_PAIR.sub(lambda m: chr(int(m.group(0), 16)),
-                             SPC.sub('', self._curtoken))
+        cleaned = SPC.sub('', self._curtoken)
+        pairs = HEX_PAIR.findall(cleaned)
+        token_bytes = bytes([int(pair, 16) for pair in pairs])
+        try:
+            token = token_bytes.decode('ascii')
+        except UnicodeDecodeError:
+            # should be kept as bytes
+            token = token_bytes
         self._add_token(token)
         self._parse1 = self._parse_main
         return j
@@ -556,6 +565,7 @@ class PSStackParser(PSBaseParser):
                 isinstance(token, float) or
                 isinstance(token, bool) or
                 isinstance(token, str) or
+                isinstance(token, bytes) or
                 isinstance(token, PSLiteral)):
                 # normal token
                 self.push((pos, token))
@@ -604,97 +614,3 @@ class PSStackParser(PSBaseParser):
         if 2 <= self.debug:
             print('nextobject: %r' % (obj,), file=sys.stderr)
         return obj
-
-
-##  Simplistic Test cases
-##
-import unittest
-class TestPSBaseParser(unittest.TestCase):
-
-    TESTDATA = br'''%!PS
-begin end
- "  @ #
-/a/BCD /Some_Name /foo#5f#xbaa
-0 +1 -2 .5 1.234
-(abc) () (abc ( def ) ghi)
-(def\040\0\0404ghi) (bach\\slask) (foo\nbaa)
-(this % is not a comment.)
-(foo
-baa)
-(foo\
-baa)
-<> <20> < 40 4020 >
-<abcd00
-12345>
-func/a/b{(c)do*}def
-[ 1 (z) ! ]
-<< /foo (bar) >>
-'''
-
-    TOKENS = [
-      (5, KWD('begin')), (11, KWD('end')), (16, KWD('"')), (19, KWD('@')),
-      (21, KWD('#')), (23, LIT('a')), (25, LIT('BCD')), (30, LIT('Some_Name')),
-      (41, LIT('foo_xbaa')), (54, 0), (56, 1), (59, -2), (62, 0.5),
-      (65, 1.234), (71, 'abc'), (77, ''), (80, 'abc ( def ) ghi'),
-      (98, 'def \x00 4ghi'), (118, 'bach\\slask'), (132, 'foo\nbaa'),
-      (143, 'this % is not a comment.'), (170, 'foo\nbaa'), (180, 'foobaa'),
-      (191, ''), (194, ' '), (199, '@@ '), (211, '\xab\xcd\x00\x124\x05'),
-      (226, KWD('func')), (230, LIT('a')), (232, LIT('b')),
-      (234, KWD('{')), (235, 'c'), (238, KWD('do*')), (241, KWD('}')),
-      (242, KWD('def')), (246, KWD('[')), (248, 1), (250, 'z'), (254, KWD('!')),
-      (256, KWD(']')), (258, KWD('<<')), (261, LIT('foo')), (266, 'bar'),
-      (272, KWD('>>'))
-      ]
-
-    OBJS = [
-      (23, LIT('a')), (25, LIT('BCD')), (30, LIT('Some_Name')),
-      (41, LIT('foo_xbaa')), (54, 0), (56, 1), (59, -2), (62, 0.5),
-      (65, 1.234), (71, 'abc'), (77, ''), (80, 'abc ( def ) ghi'),
-      (98, 'def \x00 4ghi'), (118, 'bach\\slask'), (132, 'foo\nbaa'),
-      (143, 'this % is not a comment.'), (170, 'foo\nbaa'), (180, 'foobaa'),
-      (191, ''), (194, ' '), (199, '@@ '), (211, '\xab\xcd\x00\x124\x05'),
-      (230, LIT('a')), (232, LIT('b')), (234, ['c']), (246, [1, 'z']),
-      (258, {'foo': 'bar'}),
-      ]
-
-    def get_tokens(self, s):
-        import io
-        class MyParser(PSBaseParser):
-            def flush(self):
-                self.add_results(*self.popall())
-        parser = MyParser(io.BytesIO(s))
-        r = []
-        try:
-            while 1:
-                r.append(parser.nexttoken())
-        except PSEOF:
-            pass
-        return r
-
-    def get_objects(self, s):
-        import io
-        class MyParser(PSStackParser):
-            def flush(self):
-                self.add_results(*self.popall())
-        parser = MyParser(io.BytesIO(s))
-        r = []
-        try:
-            while 1:
-                r.append(parser.nextobject())
-        except PSEOF:
-            pass
-        return r
-
-    def test_1(self):
-        tokens = self.get_tokens(self.TESTDATA)
-        print(tokens)
-        self.assertEqual(tokens, self.TOKENS)
-        return
-
-    def test_2(self):
-        objs = self.get_objects(self.TESTDATA)
-        print(objs)
-        self.assertEqual(objs, self.OBJS)
-        return
-    
-if __name__ == '__main__': unittest.main()
